==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/Form.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Form extends BusinessEntity, Infogene {     String EXT_FORM = "Form";
     String FIELD_FORM_DATEPUB = "datePub";
     String FQ_FIELD_FORM_DATEPUB = EXT_FORM + ".datePub";
     String FIELD_FORM_DATEPEREMPTION = "datePeremption";
     String FQ_FIELD_FORM_DATEPEREMPTION = EXT_FORM + ".datePeremption";
     String FIELD_FORM_FILES = "files";
     String FQ_FIELD_FORM_FILES = EXT_FORM + ".files";
     String FIELD_FORM_ATTACHMENTS = "attachments";
     String FQ_FIELD_FORM_ATTACHMENTS = EXT_FORM + ".attachments";
     String FIELD_FORM_IMPORTCONTENTHASH = "importContentHash";
     String FQ_FIELD_FORM_IMPORTCONTENTHASH = EXT_FORM + ".importContentHash";
     String FIELD_FORM_XMLSTREAM = "xmlStream";
     String FQ_FIELD_FORM_XMLSTREAM = EXT_FORM + ".xmlStream";
    /**
     * getDatePub :
     * @return Date 
     */

     Date getDatePub();

    /**
     * setDatePub :
     * @param datePub 
     */

     void setDatePub(Date datePub);

    /**
     * getDatePeremption :
     * @return Date 
     */

     Date getDatePeremption();

    /**
     * setDatePeremption :
     * @param datePeremption 
     */

     void setDatePeremption(Date datePeremption);

    /**
     * getFiles :
     * @return Set<String> 
     */

     Set<String> getFiles();

    /**
     * addFiles :
     * @param element 
     */

     void addFiles(String element);

    /**
     * removeFiles :
     * @param element 
     */

     void removeFiles(String element);

    /**
     * clearFiles :
     */

     void clearFiles();

    /**
     * getAttachments :
     * @return Set<String> 
     */

     Set<String> getAttachments();

    /**
     * addAttachments :
     * @param element 
     */

     void addAttachments(String element);

    /**
     * removeAttachments :
     * @param element 
     */

     void removeAttachments(String element);

    /**
     * clearAttachments :
     */

     void clearAttachments();

    /**
     * getImportContentHash :
     * Hash SHA1 du contenu xml du flux lors de son import.
     * @return String 
     */

     String getImportContentHash();

    /**
     * setImportContentHash :
     * @param importContentHash 
     */

     void setImportContentHash(String importContentHash);

    /**
     * getXmlStream :
     * @return String 
     */

     String getXmlStream();

    /**
     * setXmlStream :
     * @param xmlStream 
     */

     void setXmlStream(String xmlStream);

    /**
     * getId :
     * @return String 
     */

     String getId();

    /**
     * setId :
     * @param id 
     */

     void setId(String id);

    /**
     * getObjet :
     * @return String 
     */

     String getObjet();

    /**
     * setObjet :
     * @param objet 
     */

     void setObjet(String objet);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getSourceURL :
     * @return String 
     */

     String getSourceURL();

    /**
     * setSourceURL :
     * @param sourceURL 
     */

     void setSourceURL(String sourceURL);

    /**
     * getSourceText :
     * @return String 
     */

     String getSourceText();

    /**
     * setSourceText :
     * @param sourceText 
     */

     void setSourceText(String sourceText);

    /**
     * getEntity :
     * @return String 
     */

     String getEntity();

    /**
     * setEntity :
     * @param entity 
     */

     void setEntity(String entity);

    /**
     * getCountry :
     * @return String 
     */

     String getCountry();

    /**
     * setCountry :
     * @param country 
     */

     void setCountry(String country);

    /**
     * getDepartment :
     * @return String 
     */

     String getDepartment();

    /**
     * setDepartment :
     * @param department 
     */

     void setDepartment(String department);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getTag :
     * @return Set<String> 
     */

     Set<String> getTag();

    /**
     * addTag :
     * @param element 
     */

     void addTag(String element);

    /**
     * removeTag :
     * @param element 
     */

     void removeTag(String element);

    /**
     * clearTag :
     */

     void clearTag();

    /**
     * getStatus :
     * @return String 
     */

     String getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(String status);


} //Form

==> vradi-entities-0.4.0-sources.jar: com/jurismarches/vradi/entities/Form.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Form extends BusinessEntity, Infogene {     String EXT_FORM = "Form";
     String FIELD_FORM_DATEPUB = "datePub";
     String FQ_FIELD_FORM_DATEPUB = EXT_FORM + ".datePub";
     String FIELD_FORM_DATEPEREMPTION = "datePeremption";
     String FQ_FIELD_FORM_DATEPEREMPTION = EXT_FORM + ".datePeremption";
     String FIELD_FORM_FILES = "files";
     String FQ_FIELD_FORM_FILES = EXT_FORM + ".files";
     String FIELD_FORM_ATTACHMENTS = "attachments";
     String FQ_FIELD_FORM_ATTACHMENTS = EXT_FORM + ".attachments";
     String FIELD_FORM_IMPORTCONTENTHASH = "importContentHash";
     String FQ_FIELD_FORM_IMPORTCONTENTHASH = EXT_FORM + ".importContentHash";
     String FIELD_FORM_XMLSTREAM = "xmlStream";
     String FQ_FIELD_FORM_XMLSTREAM = EXT_FORM + ".xmlStream";
    /**
     * getDatePub :
     * @return Date 
     */

     Date getDatePub();

    /**
     * setDatePub :
     * @param datePub 
     */

     void setDatePub(Date datePub);

    /**
     * getDatePeremption :
     * @return Date 
     */

     Date getDatePeremption();

    /**
     * setDatePeremption :
     * @param datePeremption 
     */

     void setDatePeremption(Date datePeremption);

    /**
     * getFiles :
     * @return Set<String> 
     */

     Set<String> getFiles();

    /**
     * addFiles :
     * @param element 
     */

     void addFiles(String element);

    /**
     * removeFiles :
     * @param element 
     */

     void removeFiles(String element);

    /**
     * clearFiles :
     */

     void clearFiles();

    /**
     * getAttachments :
     * @return Set<String> 
     */

     Set<String> getAttachments();

    /**
     * addAttachments :
     * @param element 
     */

     void addAttachments(String element);

    /**
     * removeAttachments :
     * @param element 
     */

     void removeAttachments(String element);

    /**
     * clearAttachments :
     */

     void clearAttachments();

    /**
     * getImportContentHash :
     * Hash SHA1 du contenu xml du flux lors de son import.
     * @return String 
     */

     String getImportContentHash();

    /**
     * setImportContentHash :
     * @param importContentHash 
     */

     void setImportContentHash(String importContentHash);

    /**
     * getXmlStream :
     * @return String 
     */

     String getXmlStream();

    /**
     * setXmlStream :
     * @param xmlStream 
     */

     void setXmlStream(String xmlStream);

    /**
     * getId :
     * @return String 
     */

     String getId();

    /**
     * setId :
     * @param id 
     */

     void setId(String id);

    /**
     * getObjet :
     * @return String 
     */

     String getObjet();

    /**
     * setObjet :
     * @param objet 
     */

     void setObjet(String objet);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getSourceURL :
     * @return String 
     */

     String getSourceURL();

    /**
     * setSourceURL :
     * @param sourceURL 
     */

     void setSourceURL(String sourceURL);

    /**
     * getSourceText :
     * @return String 
     */

     String getSourceText();

    /**
     * setSourceText :
     * @param sourceText 
     */

     void setSourceText(String sourceText);

    /**
     * getEntity :
     * @return String 
     */

     String getEntity();

    /**
     * setEntity :
     * @param entity 
     */

     void setEntity(String entity);

    /**
     * getCountry :
     * @return String 
     */

     String getCountry();

    /**
     * setCountry :
     * @param country 
     */

     void setCountry(String country);

    /**
     * getDepartment :
     * @return String 
     */

     String getDepartment();

    /**
     * setDepartment :
     * @param department 
     */

     void setDepartment(String department);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getTag :
     * @return Set<String> 
     */

     Set<String> getTag();

    /**
     * addTag :
     * @param element 
     */

     void addTag(String element);

    /**
     * removeTag :
     * @param element 
     */

     void removeTag(String element);

    /**
     * clearTag :
     */

     void clearTag();

    /**
     * getStatus :
     * @return String 
     */

     String getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(String status);


} //Form
